local Pipeline(image, version, extra, depinstall, buildKernel) = {
  kind: "pipeline",
  type: "docker",
  name: image+"-"+version,
  steps: [
    {
      name: "build",
      image: image+":"+version,
      commands: [
        depinstall+" make gcc "+extra,
        "cd src",
        "make clean BUILD_KERNEL=\"$("+buildKernel+")\"",
        "make -j $(nproc) CONFIG_UIO=1 BUILD_KERNEL=\"$("+buildKernel+")\""
      ]
    }
  ]
};

local AptPipeline(image, version, extra, buildKernel) = Pipeline(image, version, extra, "apt update && DEBIAN_FRONTEND=noninteractive apt install -y", buildKernel);

local PacManPipeline(image, version, extra, buildKernel) = Pipeline(image, version, extra, "pacman -Syy && pacman --noconfirm -S", buildKernel);

local ApkPipeline(image, version, extra, buildKernel) = Pipeline(image, version, extra, "apk add --update gcc musl-dev", buildKernel);

local YumPipeline(image, version, extra, buildKernel) = Pipeline(image, version, extra, "yum install -y", buildKernel);

local XbpsPipeline(image, version, extra, buildKernel) = Pipeline(image, version, extra, "xbps-install -Sy", buildKernel);

[
  AptPipeline("ubuntu", "20.04", "linux-headers-generic", "ls --sort time /lib/modules/ | head -n 1"),
  AptPipeline("ubuntu", "18.04", "linux-headers-generic", "ls --sort time /lib/modules/ | head -n 1"),
  AptPipeline("ubuntu", "16.04", "linux-headers-generic", "ls --sort time /lib/modules/ | head -n 1"),

  AptPipeline("debian", "buster", "linux-headers-amd64", "ls --sort time /lib/modules/ | head -n 1"),
  AptPipeline("debian", "stretch", "linux-headers-amd64", "ls --sort time /lib/modules/ | head -n 1"),
  AptPipeline("debian", "jessie", "linux-headers-amd64", "ls --sort time /lib/modules/ | head -n 1"),

  YumPipeline("fedora", "latest", "kernel-devel kernel-headers", "ls --sort time /usr/src/kernels/ | head -n 1"),

  PacManPipeline("archlinux", "latest", "linux-headers", "ls --sort time /lib/modules/ | head -n 1"),

  ApkPipeline("alpine", "latest", "linux-headers linux-lts-dev", "ls -t /lib/modules/ | head -n 1"),

  XbpsPipeline("voidlinux/voidlinux", "latest", "linux-headers", "ls --sort time /lib/modules/ | head -n 1")
]